@@ -1,10 +1,5 @@
 package App::ChromeUtils;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-08-18'; # DATE
-our $DIST = 'App-ChromeUtils'; # DIST
-our $VERSION = '0.008'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
@@ -12,6 +7,11 @@ use Log::ger;
 
 use App::BrowserUtils ();
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-27'; # DATE
+our $DIST = 'App-ChromeUtils'; # DIST
+our $VERSION = '0.009'; # VERSION
+
 our %SPEC;
 
 $SPEC{':package'} = {
@@ -53,6 +53,19 @@ sub unpause_chrome {
     App::BrowserUtils::_do_browser('unpause', 'chrome', @_);
 }
 
+$SPEC{pause_and_unpause_chrome} = {
+    v => 1.1,
+    summary => "Pause and unpause Chrome alternately",
+    description => $App::BrowserUtils::desc_pause_and_unpause,
+    args => {
+        %App::BrowserUtils::args_common,
+        %App::BrowserUtils::argopt_periods,
+    },
+};
+sub pause_and_unpause_chrome {
+    App::BrowserUtils::_do_browser('pause_and_unpause', 'chrome', @_);
+}
+
 $SPEC{chrome_has_processes} = {
     v => 1.1,
     summary => "Check whether Chrome has processes",
@@ -158,7 +171,7 @@ App::ChromeUtils - Utilities related to Google Chrome browser
 
 =head1 VERSION
 
-This document describes version 0.008 of App::ChromeUtils (from Perl distribution App-ChromeUtils), released on 2020-08-18.
+This document describes version 0.009 of App::ChromeUtils (from Perl distribution App-ChromeUtils), released on 2021-09-27.
 
 =head1 SYNOPSIS
 
@@ -178,6 +191,8 @@ This distribution includes several utilities related to Google Chrome browser:
 
 =item * L<list-chrome-profiles>
 
+=item * L<pause-and-unpause-chrome>
+
 =item * L<pause-chrome>
 
 =item * L<ps-chrome>
@@ -199,7 +214,7 @@ This distribution includes several utilities related to Google Chrome browser:
 
 Usage:
 
- chrome_has_processes(%args) -> [status, msg, payload, meta]
+ chrome_has_processes(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check whether Chrome has processes.
 
@@ -220,12 +235,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -235,7 +250,7 @@ Return value:  (any)
 
 Usage:
 
- chrome_is_paused(%args) -> [status, msg, payload, meta]
+ chrome_is_paused(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check whether Chrome is paused.
 
@@ -258,12 +273,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -273,7 +288,7 @@ Return value:  (any)
 
 Usage:
 
- chrome_is_running(%args) -> [status, msg, payload, meta]
+ chrome_is_running(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check whether Chrome is running.
 
@@ -299,12 +314,78 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
+
+
+=head2 pause_and_unpause_chrome
+
+Usage:
+
+ pause_and_unpause_chrome(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+Pause and unpause Chrome alternately.
+
+A modern browser now runs complex web pages and applications. Despite browser's
+power management feature, these pages/tabs on the browser often still eat
+considerable CPU cycles even though they only run in the background. Pausing
+(kill -STOP) the browser processes is a simple and effective way to stop CPU
+eating on Unix and prolong your laptop battery life. It can be performed
+whenever you are not using your browser for a little while, e.g. when you are
+typing on an editor or watching a movie. When you want to use your browser
+again, simply unpause (kill -CONT) it.
+
+The C<pause-and-unpause> action pause and unpause browser in an alternate
+fashion, by default every 5 minutes and 30 seconds. This is a compromise to save
+CPU time most of the time but then give time for web applications in the browser
+to catch up during the unpause window (e.g. for WhatsApp Web to display new
+messages and sound notification.) It can be used when you are not browsing but
+still want to be notified by web applications from time to time.
+
+If you run this routine, it will start pausing and unpausing browser. When you
+want to use the browser, press Ctrl-C to interrupt the routine. Then after you
+are done with the browser and want to pause-and-unpause again, you can re-run
+this routine.
+
+You can customize the periods via the C<periods> option.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<periods> => I<array[duration]>
+
+Pause and unpause times, in seconds.
+
+For example, to pause for 5 minutes, then unpause 10 seconds, then pause for 2
+minutes, then unpause for 30 seconds (then repeat the pattern), you can use:
+
+ 300,10,120,30
+
+=item * B<users> => I<array[unix::local_uid]>
+
+Kill browser processes that belong to certain user(s) only.
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -314,17 +395,18 @@ Return value:  (any)
 
 Usage:
 
- pause_chrome(%args) -> [status, msg, payload, meta]
+ pause_chrome(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Pause (kill -STOP) Chrome.
 
 A modern browser now runs complex web pages and applications. Despite browser's
 power management feature, these pages/tabs on the browser often still eat
-considerable CPU cycles even though they only run in the background. Stopping
+considerable CPU cycles even though they only run in the background. Pausing
 (kill -STOP) the browser processes is a simple and effective way to stop CPU
-eating on Unix. It can be performed whenever you are not using your browser for
-a little while, e.g. when you are typing on an editor or watching a movie. When
-you want to use your browser again, simply unpause it.
+eating on Unix and prolong your laptop battery life. It can be performed
+whenever you are not using your browser for a little while, e.g. when you are
+typing on an editor or watching a movie. When you want to use your browser
+again, simply unpause (kill -CONT) it.
 
 This function is not exported.
 
@@ -341,12 +423,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -356,7 +438,7 @@ Return value:  (any)
 
 Usage:
 
- ps_chrome(%args) -> [status, msg, payload, meta]
+ ps_chrome(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 List Chrome processes.
 
@@ -375,12 +457,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -390,7 +472,7 @@ Return value:  (any)
 
 Usage:
 
- restart_chrome(%args) -> [status, msg, payload, meta]
+ restart_chrome(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Restart chrome.
 
@@ -422,12 +504,12 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -437,7 +519,7 @@ Return value:  (any)
 
 Usage:
 
- start_chrome(%args) -> [status, msg, payload, meta]
+ start_chrome(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Start chrome if not already started.
 
@@ -469,12 +551,12 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -484,7 +566,7 @@ Return value:  (any)
 
 Usage:
 
- terminate_chrome(%args) -> [status, msg, payload, meta]
+ terminate_chrome(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Terminate  (kill -KILL) Chrome.
 
@@ -503,12 +585,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -518,7 +600,7 @@ Return value:  (any)
 
 Usage:
 
- unpause_chrome(%args) -> [status, msg, payload, meta]
+ unpause_chrome(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Unpause (resume, continue, kill -CONT) Chrome.
 
@@ -537,12 +619,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -554,14 +636,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Chrome
 
 Source repository is at L<https://github.com/perlancar/perl-App-ChromeUtils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ChromeUtils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 Some other CLI utilities related to Chrome: L<dump-chrome-history> (from
@@ -579,11 +653,36 @@ L<App::BrowserUtils>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ChromeUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
